# src/simple_hwp2pdf/__init__.py
import os
from .office_converter import convert_with_office
from .standalone_converter import convert_standalone

def convert(input_path: str, output_path: str, method: str = 'auto'):
    """
    HWP(X) 파일을 PDF로 변환합니다.

    :param input_path: 변환할 HWP 또는 HWPX 파일 경로
    :param output_path: 저장할 PDF 파일 경로
    :param method: 변환 방법 선택 ('auto', 'standalone', 'office')
                   - 'auto': 파일 확장자가 .hwpx이면 'standalone', .hwp이면 'office' 시도
                   - 'standalone': 한컴오피스 없이 변환 (hwpx 권장)
                   - 'office': 한컴오피스를 이용해 변환 (Windows 전용)
    """
    if not os.path.exists(input_path):
        raise FileNotFoundError(f"입력 파일을 찾을 수 없습니다: {input_path}")

    if method == 'standalone':
        print("INFO: Standalone 엔진으로 변환을 시작합니다.")
        convert_standalone(input_path, output_path)
    elif method == 'office':
        print("INFO: Office 엔진으로 변환을 시작합니다.")
        convert_with_office(input_path, output_path)
    elif method == 'auto':
        print("INFO: Auto 모드로 변환을 시작합니다.")
        if input_path.lower().endswith('.hwpx'):
            try:
                print("INFO: .hwpx 파일이므로 Standalone 엔진을 먼저 시도합니다.")
                convert_standalone(input_path, output_path)
            except Exception as e:
                print(f"WARNING: Standalone 엔진 실패({e}). Office 엔진으로 재시도합니다.")
                try:
                    convert_with_office(input_path, output_path)
                except Exception as final_e:
                    raise RuntimeError("모든 변환 엔진 실행에 실패했습니다.") from final_e
        else: # .hwp 파일인 경우
            print("INFO: .hwp 파일이므로 Office 엔진을 시도합니다.")
            convert_with_office(input_path, output_path)
    else:
        raise ValueError("잘못된 method 값입니다. 'auto', 'standalone', 'office' 중 하나를 선택하세요.")