# src/simple_hwp2pdf/office_converter.py
import os
import sys

# office 의존성이 설치되었을 때만 win32com을 import
try:
    import win32com.client as win32
except ImportError:
    win32 = None

def convert_with_office(input_path: str, output_path: str):
    if not win32:
        raise ImportError("Office 엔진을 사용하려면 'pip install simple-hwp2pdf[office]'로 pywin32를 설치해야 합니다.")
    if sys.platform != "win32":
        raise OSError("Office 엔진은 Windows 환경에서만 사용할 수 있습니다.")

    hwp = None
    try:
        output_dir = os.path.dirname(output_path)
        if not os.path.exists(output_dir):
            os.makedirs(output_dir)

        hwp = win32.gencache.EnsureDispatch("HWPFrame.HwpObject")
        hwp.RegisterModule("FilePathCheckDLL", "FilePathCheckerModule")
        hwp.Open(input_path)
        hwp.SaveAs(output_path, "PDF")
    finally:
        if hwp:
            hwp.Quit()